CgroupsMetadataCollector

Struct CgroupsMetadataCollector 

pub struct CgroupsMetadataCollector { /* private fields */ }
A metadata collector that observes Linux “Control Groups” (cgroups).

This collector specifically tracks cgroup controllers attached to container workloads using simple regex-based matching against the controller path, and maintains a mapping of controller inodes to the container ID extracted from the controller path.

This is specifically used to support client-based Origin Detection in DogStatsD, where clients will either send their detected container ID or the inode of their cgroup controller. A canonical container ID must always be used for origin enrichment, so this mapping allows resolving controller inodes to their canonical container ID.

Implementations

Source

impl CgroupsMetadataCollector

pub async fn new( cgroups_config: &CgroupsConfiguration, health: Health, interner: GenericMapInterner, ) -> Result<Self, GenericError>

Creates a new CgroupsMetadataCollector from the given cgroups configuration.

Errors

If a valid cgroups hierarchy can not be located at the configured path, an error will be returned.