pub struct ContainerdMetadataCollector { /* private fields */ }Expand description
A metadata collector that watches for updates from containerd.
Implementations
Sourceimpl ContainerdMetadataCollector
impl ContainerdMetadataCollector
Sourcepub async fn new(
socket_path: Option<PathBuf>,
containerd_config: &ContainerdConfiguration,
health: Health,
tag_interner: GenericMapInterner,
) -> Result<Self, GenericError>
pub async fn new( socket_path: Option<PathBuf>, containerd_config: &ContainerdConfiguration, health: Health, tag_interner: GenericMapInterner, ) -> Result<Self, GenericError>
Creates a new ContainerdMetadataCollector from the given containerd configuration.
If socket_path is given, that path is used. Otherwise, well-known paths are probed.
Errors
If the containerd gRPC client can’t be created, or listing the namespaces in the containerd runtime fails, an error will be returned.