pub struct ContainerdMetadataCollector { /* private fields */ }Expand description
A metadata collector that watches for updates from containerd.
Implementations
Sourceimpl ContainerdMetadataCollector
impl ContainerdMetadataCollector
Sourcepub async fn from_configuration(
config: &GenericConfiguration,
health: Health,
tag_interner: GenericMapInterner,
) -> Result<Self, GenericError>
pub async fn from_configuration( config: &GenericConfiguration, health: Health, tag_interner: GenericMapInterner, ) -> Result<Self, GenericError>
Creates a new ContainerdMetadataCollector from the given configuration.
Errors
If the containerd gRPC client can’t be created, or listing the namespaces in the containerd runtime fails, an error will be returned.